# -*- coding: utf-8 -*-

from bts.http_rpc import HTTPRPC  # noqa

from bts import metadata


__version__ = metadata.version
__author__ = metadata.authors[0]
__license__ = metadata.license
__copyright__ = metadata.copyright
